@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 #
-#    pyars pyARS.
+#    pyard pyARD.
 #    Copyright (c) 2018 Be The Match operated by National Marrow Donor Program. All Rights Reserved.
 #
 #    This library is free software; you can redistribute it and/or modify it
@@ -21,8 +21,7 @@
 #    > http://www.fsf.org/licensing/licenses/lgpl.html
 #    > http://www.opensource.org/licenses/lgpl-license.php
 #
-from __future__ import absolute_import
 from .pyard import ARD
 
 __author__ = """NMDP Bioinformatics"""
-__version__ = '0.0.13'
+__version__ = '0.4.0'
